@@ -17,7 +17,7 @@
     provides methods and functions to convert SAML classes to and from strings.
 """
 
-__version__ = "4.4.0"
+__version__ = "4.5.0"
 
 import logging
 import six
@@ -36,6 +36,7 @@ except ImportError:
         import cElementTree as ElementTree
     except ImportError:
         from elementtree import ElementTree
+import defusedxml.ElementTree
 
 root_logger = logging.getLogger(__name__)
 root_logger.level = logging.NOTSET
@@ -87,7 +88,7 @@ def create_class_from_xml_string(target_class, xml_string):
     """
     if not isinstance(xml_string, six.binary_type):
         xml_string = xml_string.encode('utf-8')
-    tree = ElementTree.fromstring(xml_string)
+    tree = defusedxml.ElementTree.fromstring(xml_string)
     return create_class_from_element_tree(target_class, tree)
 
 
@@ -269,7 +270,7 @@ class ExtensionElement(object):
 
 
 def extension_element_from_string(xml_string):
-    element_tree = ElementTree.fromstring(xml_string)
+    element_tree = defusedxml.ElementTree.fromstring(xml_string)
     return _extension_element_from_element_tree(element_tree)
 
 
@@ -599,8 +600,8 @@ class SamlBase(ExtensionContainer):
                 self.assertion.advice.encrypted_assertion:
             if tmp_encrypted_assertion.encrypted_data is None:
                 prefix_map = self.get_prefix_map([
-                                                     tmp_encrypted_assertion._to_element_tree().find(
-                                                         assertion_tag)])
+                    tmp_encrypted_assertion._to_element_tree().find(
+                        assertion_tag)])
                 tree = self._to_element_tree()
                 encs = tree.find(assertion_tag).find(advice_tag).findall(
                     tmp_encrypted_assertion._to_element_tree().tag)
@@ -1017,3 +1018,19 @@ def extension_elements_as_dict(extension_elements, onts):
         except KeyError:
             res[elem.c_tag] = [elem]
     return res
+
+
+REQUIRED = 2
+
+
+def is_required_attribute(cls, attr):
+    """
+    Check if the attribute is a required attribute for a specific SamlBase
+    class.
+    
+    :param cls: The class 
+    :param attr: An attribute, note it must be the name of the attribute 
+        that appears in the XSD in which the class is defined.
+    :return: True if required
+    """
+    return cls.c_attributes[attr][REQUIRED]
